==> ngtcp2-1.8.1.tar.xz: ngtcp2-1.8.1/tests/ngtcp2_conv_test.h <==
/*
 * ngtcp2
 *
 * Copyright (c) 2017 ngtcp2 contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
#ifndef NGTCP2_CONV_TEST_H
#define NGTCP2_CONV_TEST_H

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif /* defined(HAVE_CONFIG_H) */

#define MUNIT_ENABLE_ASSERT_ALIASES

#include "munit.h"

extern const MunitSuite conv_suite;

munit_void_test_decl(test_ngtcp2_get_varint);
munit_void_test_decl(test_ngtcp2_get_uvarintlen);
munit_void_test_decl(test_ngtcp2_put_uvarintlen);
munit_void_test_decl(test_ngtcp2_get_uint64be);
munit_void_test_decl(test_ngtcp2_get_uint32be);
munit_void_test_decl(test_ngtcp2_get_uint24be);
munit_void_test_decl(test_ngtcp2_get_uint16be);
munit_void_test_decl(test_ngtcp2_get_uint16);
munit_void_test_decl(test_ngtcp2_put_pkt_num);

#endif /* !defined(NGTCP2_CONV_TEST_H) */

==> ngtcp2_1.16.0.orig.tar.xz: ngtcp2-1.16.0/tests/ngtcp2_conv_test.h <==
/*
 * ngtcp2
 *
 * Copyright (c) 2017 ngtcp2 contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
#ifndef NGTCP2_CONV_TEST_H
#define NGTCP2_CONV_TEST_H

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif /* defined(HAVE_CONFIG_H) */

#define MUNIT_ENABLE_ASSERT_ALIASES

#include "munit.h"

extern const MunitSuite conv_suite;

munit_void_test_decl(test_ngtcp2_get_varint)
munit_void_test_decl(test_ngtcp2_get_uvarintlen)
munit_void_test_decl(test_ngtcp2_put_uvarintlen)
munit_void_test_decl(test_ngtcp2_get_uint64be)
munit_void_test_decl(test_ngtcp2_get_uint32be)
munit_void_test_decl(test_ngtcp2_get_uint24be)
munit_void_test_decl(test_ngtcp2_get_uint16be)
munit_void_test_decl(test_ngtcp2_get_uint16)
munit_void_test_decl(test_ngtcp2_put_pkt_num)

#endif /* !defined(NGTCP2_CONV_TEST_H) */
